Clazz.declarePackage("J.adapter.smarter");
Clazz.declareInterface(J.adapter.smarter, "MSInterface");
;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
